==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/datashare/kotlin/outputs/GetADLSGen2FileSystemDataSetMappingResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datashare.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * An ADLS Gen2 file system data set mapping.
 * @property dataSetId The id of the source data set.
 * @property dataSetMappingStatus Gets the status of the data set mapping.
 * @property fileSystem The file system name.
 * @property id The resource id of the azure resource
 * @property kind Kind of data set mapping.
 * Expected value is 'AdlsGen2FileSystem'.
 * @property name Name of the azure resource
 * @property provisioningState Provisioning state of the data set mapping.
 * @property resourceGroup Resource group of storage account.
 * @property storageAccountName Storage account name of the source data set.
 * @property subscriptionId Subscription id of storage account.
 * @property systemData System Data of the Azure resource.
 * @property type Type of the azure resource
 */
public data class GetADLSGen2FileSystemDataSetMappingResult(
    public val dataSetId: String,
    public val dataSetMappingStatus: String,
    public val fileSystem: String,
    public val id: String,
    public val kind: String,
    public val name: String,
    public val provisioningState: String,
    public val resourceGroup: String,
    public val storageAccountName: String,
    public val subscriptionId: String,
    public val systemData: SystemDataResponse,
    public val type: String,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.datashare.outputs.GetADLSGen2FileSystemDataSetMappingResult):
            GetADLSGen2FileSystemDataSetMappingResult = GetADLSGen2FileSystemDataSetMappingResult(
            dataSetId = javaType.dataSetId(),
            dataSetMappingStatus = javaType.dataSetMappingStatus(),
            fileSystem = javaType.fileSystem(),
            id = javaType.id(),
            kind = javaType.kind(),
            name = javaType.name(),
            provisioningState = javaType.provisioningState(),
            resourceGroup = javaType.resourceGroup(),
            storageAccountName = javaType.storageAccountName(),
            subscriptionId = javaType.subscriptionId(),
            systemData = javaType.systemData().let({ args0 ->
                com.pulumi.azurenative.datashare.kotlin.outputs.SystemDataResponse.Companion.toKotlin(args0)
            }),
            type = javaType.type(),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/datashare/kotlin/outputs/GetADLSGen2FileSystemDataSetMappingResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datashare.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * An ADLS Gen2 file system data set mapping.
 * @property dataSetId The id of the source data set.
 * @property dataSetMappingStatus Gets the status of the data set mapping.
 * @property fileSystem The file system name.
 * @property id The resource id of the azure resource
 * @property kind Kind of data set mapping.
 * Expected value is 'AdlsGen2FileSystem'.
 * @property name Name of the azure resource
 * @property provisioningState Provisioning state of the data set mapping.
 * @property resourceGroup Resource group of storage account.
 * @property storageAccountName Storage account name of the source data set.
 * @property subscriptionId Subscription id of storage account.
 * @property systemData System Data of the Azure resource.
 * @property type Type of the azure resource
 */
public data class GetADLSGen2FileSystemDataSetMappingResult(
    public val dataSetId: String,
    public val dataSetMappingStatus: String,
    public val fileSystem: String,
    public val id: String,
    public val kind: String,
    public val name: String,
    public val provisioningState: String,
    public val resourceGroup: String,
    public val storageAccountName: String,
    public val subscriptionId: String,
    public val systemData: SystemDataResponse,
    public val type: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.datashare.outputs.GetADLSGen2FileSystemDataSetMappingResult): GetADLSGen2FileSystemDataSetMappingResult = GetADLSGen2FileSystemDataSetMappingResult(
            dataSetId = javaType.dataSetId(),
            dataSetMappingStatus = javaType.dataSetMappingStatus(),
            fileSystem = javaType.fileSystem(),
            id = javaType.id(),
            kind = javaType.kind(),
            name = javaType.name(),
            provisioningState = javaType.provisioningState(),
            resourceGroup = javaType.resourceGroup(),
            storageAccountName = javaType.storageAccountName(),
            subscriptionId = javaType.subscriptionId(),
            systemData = javaType.systemData().let({ args0 ->
                com.pulumi.azurenative.datashare.kotlin.outputs.SystemDataResponse.Companion.toKotlin(args0)
            }),
            type = javaType.type(),
        )
    }
}
